==> piwigo-2.5.3.zip: piwigo/language/eo_EO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['webmaster login can\'t contain characters \' or "'] = 'la retejestra salutnomo ne devas enteni la signoj \' aŭ "';
$lang['user password given by your host provider'] = 'uzanto-pasvorto provizita de via provizanto de gastigo';
$lang['user login given by your host provider'] = 'uzanto-salutnomo provizita de via provizanto de gastigo';
$lang['please enter your password again'] = 'bonvolu tajpi vian pasvorton denove';
$lang['enter a login for webmaster'] = 'entajpu retestran salutnomon';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'per ĝi, prefiksoj aldoniĝos sur la nomojn de la datumtabelo (ebligas al vi pli bone mastrumi viajn tabelojn)';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi devus vin direkti al la subtenoservo de via provizanto de gastigo, kaj serĉi kiel vi mem povas interŝanĝi al PHP 5.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Vi povas elŝuti la agordan dosieron kaj alŝuti ĝin al la dosierujo "local/config" dum via instalado.';
$lang['Just another Piwigo gallery'] = 'Nur alia bildogalerio ĉe Piwigo';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Eblas, ke Piwigo provos interŝanĝi vian agordon al PHP 5 kreante aŭ modifiante iun .htaccess-dosieron.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notu, ke eblas ŝanĝi vian agordon mem kaj poste restartigi Piwigo.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Gardu ĝin sekreta, ĝi ebligas al vi aliri la administran panelon';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Ĝi montriĝos al vizitantoj. Necesas por reteja administrado';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ŝajnas, ke via retejgastiganto nuntempe funkciigas PHP %s.';
$lang['Welcome to your new installation of Piwigo!'] = 'Bonvenon al via nova instalado de Piwigo!';
$lang['also given by your host provider'] = 'ankaŭ provizita de via provizanto de gastigo';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Ĉu vi bezonas helpon? Starigu demandon ĉe la <a href="%s">mesaĝtabulo de Piwigo</a>.';
$lang['Try to configure PHP 5'] = 'Provu agordi PHP 5';
$lang['Sorry!'] = 'Pardonu!';
$lang['Visitors will be able to contact site administrator with this mail'] = 'La vizitantoj povos uzi tiun retadreson por kontakti la retestron';
$lang['Welcome to my photo gallery'] = 'Bonvenon al mia foto-galerio';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ne kapablis agordi PHP 5.';
$lang['verification'] = 'kontrolado';
$lang['Hope to see you back soon.'] = 'Ĝis baldaŭa vizito via.';
$lang['Start Install'] = 'Komenci la instaladon';
$lang['Password ']['confirm'] = 'Pasvorto [konfirmu]';
$lang['PHP 5 is required'] = 'Necesas PHP 5';
$lang['User'] = 'Uzanto';
$lang['Download the config file'] = 'Elŝuti la agordan dosieron';
$lang['Database table prefix'] = 'Prefikso de datumtabeloj';
$lang['Host'] = 'Gastiga komputilo';
$lang['Installation'] = 'Instalado';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne hezitu viziti niajn forumojn por obteni helpon: %s';
$lang['Default gallery language'] = 'Apriora galeri-lingvo';
$lang['Database name'] = 'Nomo de datumbazo';
$lang['Database configuration'] = 'Agordo de datumbazo';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Anstataŭa solvo estas kopii la tekston en la ĉisupra tekstujo kaj alglui ĝin al la dosiero "local/config/database.inc.php" (Averto: nepras ke database.inc.php nur entenu tion, kio ĉeestas en la tekstujo, sen alineo nek spaceto)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La kreado de local/config/database.inc.php malsukcesis.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Sukcesis kontektado kun la servilo, sed ne eblis konektado kun la datumbazo';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulon, la instalado de Piwigo plenumiĝis';
$lang['Can\'t connect to server'] = 'Ne eblas konekti kun la servilo';
$lang['Basic configuration'] = 'Baza agordo';
$lang['Admin configuration'] = 'Administra agordo';
$lang['localhost or other, supplied by your host provider'] = 'loka gasto (localhost) aŭ alia, provizita de via provizanto de gastigo';
?>

==> piwigo-16.0.0.zip: piwigo/language/eo_EO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['webmaster login can\'t contain characters \' or "'] = 'la retejestra salutnomo ne devas enteni la signoj \' aŭ "';
$lang['user password given by your host provider'] = 'uzanto-pasvorto provizita de via provizanto de gastigo';
$lang['user login given by your host provider'] = 'uzanto-salutnomo provizita de via provizanto de gastigo';
$lang['please enter your password again'] = 'bonvolu tajpi vian pasvorton denove';
$lang['enter a login for webmaster'] = 'entajpu retestran salutnomon';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'per ĝi, prefiksoj aldoniĝos sur la nomojn de la datumtabelo (ebligas al vi pli bone mastrumi viajn tabelojn)';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi devus vin direkti al la subtenoservo de via provizanto de gastigo, kaj serĉi kiel vi mem povas interŝanĝi al PHP 5.2';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Vi povas elŝuti la agordan dosieron kaj alŝuti ĝin al la dosierujo "local/config" dum via instalado.';
$lang['Just another Piwigo gallery'] = 'Nur alia bildogalerio ĉe Piwigo';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Eblas, ke Piwigo provos interŝanĝi vian agordon al PHP 5.2 kreante aŭ modifiante iun .htaccess-dosieron.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notu, ke eblas ŝanĝi vian agordon mem kaj poste restartigi Piwigo.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Gardu ĝin sekreta, ĝi ebligas al vi aliri la administran panelon';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Ĝi montriĝos al vizitantoj. Necesas por reteja administrado';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ŝajnas, ke via retejgastiganto nuntempe funkciigas PHP %s.';
$lang['Welcome to your new installation of Piwigo!'] = 'Bonvenon al via nova instalado de Piwigo!';
$lang['also given by your host provider'] = 'ankaŭ provizita de via provizanto de gastigo';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Ĉu vi bezonas helpon? Starigu demandon ĉe la <a href="%s">mesaĝtabulo de Piwigo</a>.';
$lang['Try to configure PHP 5'] = 'Provu agordi PHP 5.2';
$lang['Sorry!'] = 'Pardonu!';
$lang['Visitors will be able to contact site administrator with this mail'] = 'La vizitantoj povos uzi tiun retadreson por kontakti la retestron';
$lang['Welcome to my photo gallery'] = 'Bonvenon al mia foto-galerio';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ne kapablis agordi PHP 5.2';
$lang['verification'] = 'kontrolado';
$lang['Hope to see you back soon.'] = 'Ĝis baldaŭa vizito via.';
$lang['Start Install'] = 'Komenci la instaladon';
$lang['Password ']['confirm'] = 'Pasvorto [konfirmu]';
$lang['PHP 5 is required'] = 'Necesas PHP 5.2';
$lang['User'] = 'Uzanto';
$lang['Download the config file'] = 'Elŝuti la agordan dosieron';
$lang['Database table prefix'] = 'Prefikso de datumtabeloj';
$lang['Host'] = 'Gastiga komputilo';
$lang['Installation'] = 'Instalado';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne hezitu viziti niajn forumojn por obteni helpon: %s';
$lang['Default gallery language'] = 'Apriora galeri-lingvo';
$lang['Database name'] = 'Nomo de datumbazo';
$lang['Database configuration'] = 'Agordo de datumbazo';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Anstataŭa solvo estas kopii la tekston en la ĉisupra tekstujo kaj alglui ĝin al la dosiero "local/config/database.inc.php" (Averto: nepras ke database.inc.php nur entenu tion, kio ĉeestas en la tekstujo, sen alineo nek spaceto)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La kreado de local/config/database.inc.php malsukcesis.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Sukcesis kontektado kun la servilo, sed ne eblis konektado kun la datumbazo';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulon, la instalado de Piwigo plenumiĝis';
$lang['Can\'t connect to server'] = 'Ne eblas konekti kun la servilo';
$lang['Basic configuration'] = 'Baza agordo';
$lang['Admin configuration'] = 'Administra agordo';
$lang['localhost or other, supplied by your host provider'] = 'loka gasto (localhost) aŭ alia, provizita de via provizanto de gastigo';
